# pycocowriter

This library contains tools to assist in writing COCO-format annotation files.  
Contains [typing and constructors](https://nodd-tools.github.io/pycocowriter/api/coco) to assist in building a COCO-format file from scratch and then [dump it to json](https://nodd-tools.github.io/pycocowriter/api/coco/#pycocowriter.coco.COCOData.to_json).
Contains [helpful conversion tools](https://nodd-tools.github.io/pycocowriter/api/csv2coco) to assist in converting annotations in flat files or from SQL queries into COCO format.

# Installation

Install the latest stable release [from pypi](https://pypi.org/project/pycocowriter/)  

    pip install pycocowriter

Or install the development version [from github](https://github.com/nodd-tools/pycocowriter)

    pip install git+https://github.com/nodd-tools/pycocowriter.git

# Contributing

We would love to have your contributions that improve current functionality, fix bugs, or add new features
that facilitate parsing generic image annotation formats into COCO format.  See [the contributing guidelines](CONTRIBUTING.md) for more info.

# Disclaimer

This repository is a scientific product and is not official communication of the National Oceanic and
Atmospheric Administration, or the United States Department of Commerce. All NOAA GitHub project
code is provided on an ‘as is’ basis and the user assumes responsibility for its use. Any claims against the
Department of Commerce or Department of Commerce bureaus stemming from the use of this GitHub
project will be governed by all applicable Federal law. Any reference to specific commercial products,
processes, or services by service mark, trademark, manufacturer, or otherwise, does not constitute or
imply their endorsement, recommendation or favoring by the Department of Commerce. The Department
of Commerce seal and logo, or the seal and logo of a DOC bureau, shall not be used in any manner to
imply endorsement of any commercial product or activity by DOC or the United States Government.
